@@ -1,5 +1,5 @@
 package Test::WWW::Mechanize::Mojo;
-$Test::WWW::Mechanize::Mojo::VERSION = '0.0.20';
+$Test::WWW::Mechanize::Mojo::VERSION = '0.0.21';
 use strict;
 use warnings;
 
@@ -60,7 +60,7 @@ sub clear_host
 
     delete( $self->{host} );
 
-    return;
+    return ();
 }
 
 sub has_host
@@ -226,8 +226,11 @@ sub _check_external_request
 {
     my ( $self, $request ) = @_;
 
-    # If there's no host then definatley not an external request.
-    $request->uri->can('host_port') or return;
+    # If there's no host then definitely not an external request.
+    if ( not $request->uri->can('host_port') )
+    {
+        return undef;
+    }
 
     if ( $self->allow_external && $request->uri->host_port ne 'localhost:80' )
     {
@@ -300,7 +303,7 @@ Test::WWW::Mechanize::Mojo - Test::WWW::Mechanize for Mojo / Mojolicious
 
 =head1 VERSION
 
-version 0.0.20
+version 0.0.21
 
 =head1 SYNOPSIS
 
@@ -624,36 +627,10 @@ Copyright (C) 2005-8, Leon Brocard
 This module is free software; you can redistribute it or modify it
 under the same terms as Perl itself.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2005 by Leon Brocard.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/perl-test-www-mechanize-mojo/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc Test::WWW::Mechanize::Mojo
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -671,14 +648,6 @@ L<https://metacpan.org/release/Test-WWW-Mechanize-Mojo>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Test-WWW-Mechanize-Mojo>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -687,22 +656,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-WWW-Mechanize-Mojo>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Test-WWW-Mechanize-Mojo>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Test-WWW-Mechanize-Mojo>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -751,4 +704,24 @@ L<https://github.com/shlomif/perl-test-www-mechanize-mojo>
 
   git clone git://github.com/shlomif/perl-test-www-mechanize-mojo.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-test-www-mechanize-mojo/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2005 by Leon Brocard.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
